@@ -10,21 +10,21 @@
 // Use the kdepim version
 #include "kontact-version.h"
 
-#include "mainwindow.h"
 #include "kontact_debug.h"
+#include "mainwindow.h"
 #include "prefs.h"
 using namespace Kontact;
 
+#include <KontactInterface/PimUniqueApplication>
 #include <KontactInterface/Plugin>
 #include <KontactInterface/UniqueAppHandler>
-#include <KontactInterface/PimUniqueApplication>
 
 #include <KAboutData>
+#include <KCrash>
 #include <KLocalizedString>
 #include <KService>
 #include <KServiceTypeTrader>
 #include <KWindowSystem>
-#include <KCrash>
 
 #include <QCommandLineParser>
 #include <QDBusConnection>
@@ -47,7 +47,7 @@ public:
         KLocalizedString::setApplicationDomain("kontact");
     }
 
-    ~KontactApp()
+    ~KontactApp() override
     {
     }
 
@@ -71,9 +71,8 @@ private:
 
 static void listPlugins()
 {
-    const KService::List offers = KServiceTypeTrader::self()->query(
-        QStringLiteral("Kontact/Plugin"),
-        QStringLiteral("[X-KDE-KontactPluginVersion] == %1").arg(KONTACT_PLUGIN_VERSION));
+    const KService::List offers =
+        KServiceTypeTrader::self()->query(QStringLiteral("Kontact/Plugin"), QStringLiteral("[X-KDE-KontactPluginVersion] == %1").arg(KONTACT_PLUGIN_VERSION));
     const KService::List::ConstIterator end(offers.end());
     for (KService::List::ConstIterator it = offers.begin(); it != end; ++it) {
         KService::Ptr service = (*it);
@@ -88,21 +87,14 @@ static void listPlugins()
 
 static void loadCommandLineOptions(QCommandLineParser *parser)
 {
-    parser->addOption(QCommandLineOption(
-                          QStringLiteral("module"),
-                          i18n("Start with a specific Kontact module"),
-                          QStringLiteral("module")));
-    parser->addOption(QCommandLineOption(
-                          QStringLiteral("iconify"),
-                          i18n("Start in iconified (minimized) mode")));
-    parser->addOption(QCommandLineOption(
-                          QStringLiteral("list"),
-                          i18n("List all possible modules and exit")));
+    parser->addOption(QCommandLineOption(QStringLiteral("module"), i18n("Start with a specific Kontact module"), QStringLiteral("module")));
+    parser->addOption(QCommandLineOption(QStringLiteral("iconify"), i18n("Start in iconified (minimized) mode")));
+    parser->addOption(QCommandLineOption(QStringLiteral("list"), i18n("List all possible modules and exit")));
 }
 
 int KontactApp::activate(const QStringList &args, const QString &workingDir)
 {
-    Q_UNUSED(workingDir);
+    Q_UNUSED(workingDir)
 
     QCommandLineParser parser;
     loadCommandLineOptions(&parser);
@@ -163,7 +155,7 @@ int main(int argc, char **argv)
                      QLatin1String(version),
                      i18n("KDE personal information manager"),
                      KAboutLicense::GPL,
-                     i18n("Copyright © 2001–2020 Kontact authors"),
+                     i18n("Copyright © 2001–2021 Kontact authors"),
                      QString(),
                      QStringLiteral("https://userbase.kde.org/Kontact"));
 
@@ -177,8 +169,7 @@ int main(int argc, char **argv)
     about.addAuthor(i18n("Ingo Kl\303\266cker"), QString(), QStringLiteral("kloecker@kde.org"));
     about.addAuthor(i18n("Sven L\303\274ppken"), QString(), QStringLiteral("sven@kde.org"));
     about.addAuthor(i18n("Zack Rusin"), QString(), QStringLiteral("zack@kde.org"));
-    about.addAuthor(i18n("Matthias Hoelzer-Kluepfel"),
-                    i18n("Original Author"), QStringLiteral("mhk@kde.org"));
+    about.addAuthor(i18n("Matthias Hoelzer-Kluepfel"), i18n("Original Author"), QStringLiteral("mhk@kde.org"));
     about.addCredit(i18n("Torgny Nyblom"), i18n("Git Migration"), QStringLiteral("nyblom@kde.org"));
     about.setOrganizationDomain("kde.org");
     app.setAboutData(about);
@@ -206,7 +197,7 @@ int main(int argc, char **argv)
     if (!app.isSessionRestored()) {
         // There can only be one main window
         if (KMainWindow::canBeRestored(1)) {
-            auto *mainWindow = new MainWindow();
+            auto mainWindow = new MainWindow();
             app.setMainWindow(mainWindow);
             app.setSessionRestored(true);
             mainWindow->show();
